spacepy.data_assimilation.forecast — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.forecast

`spacepy.data_assimilation.` `forecast`(Tnow+Twindow)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »